@@ -1,5 +1,6 @@
 from enum import Enum
 from pathlib import Path, PosixPath
+from uuid import UUID
 
 from yaml.emitter import Emitter
 from yaml.representer import SafeRepresenter
@@ -21,6 +22,12 @@ def _represent_enum(obj, value: Enum):
     return SafeRepresenter.represent_str(obj, value.value)
 
 
+def _represent_uuid(obj, value: UUID):
+    from yaml.representer import SafeRepresenter
+
+    return SafeRepresenter.represent_str(obj, str(value))
+
+
 class CustomRepresenter(SafeRepresenter):
     pass
 
@@ -28,6 +35,7 @@ class CustomRepresenter(SafeRepresenter):
 CustomRepresenter.add_representer(Path, _represent_hasstr)
 CustomRepresenter.add_representer(PosixPath, _represent_hasstr)
 CustomRepresenter.add_multi_representer(Enum, _represent_enum)
+CustomRepresenter.add_multi_representer(UUID, _represent_uuid)
 
 
 class CustomDumper(Emitter, Serializer, CustomRepresenter, Resolver):
